@@ -7,8 +7,9 @@ use URI::Escape::XS qw/uri_escape/;
 use Digest::SHA qw/sha1_hex/;
 use parent qw/Cache::Memcached::Fast/;
 use POSIX::AtFork;
+use Scalar::Util qw/weaken/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $SANITIZE_METHOD = sub {
     my $key = shift;
     $key = uri_escape($key,"\x00-\x20\x7f-\xff");
@@ -23,8 +24,9 @@ sub new {
     my %args = ref $_[0] ? %{$_[0]} : @_;
     my $mem = $class->SUPER::new(\%args);
     # fork safe
+    weaken(my $mem_weaken = $mem);
     POSIX::AtFork->add_to_child(sub {
-        $mem->disconnect_all;
+        eval { $mem_weaken->disconnect_all };
     });
     $mem;
 }
